#[repr(C)]pub struct WasmBenchConfig {Show 19 fields
pub working_dir_ptr: *const u8,
pub working_dir_len: usize,
pub stdout_path_ptr: *const u8,
pub stdout_path_len: usize,
pub stderr_path_ptr: *const u8,
pub stderr_path_len: usize,
pub stdin_path_ptr: *const u8,
pub stdin_path_len: usize,
pub compilation_timer: *mut u8,
pub compilation_start: extern "C" fn(*mut u8),
pub compilation_end: extern "C" fn(*mut u8),
pub instantiation_timer: *mut u8,
pub instantiation_start: extern "C" fn(*mut u8),
pub instantiation_end: extern "C" fn(*mut u8),
pub execution_timer: *mut u8,
pub execution_start: extern "C" fn(*mut u8),
pub execution_end: extern "C" fn(*mut u8),
pub execution_flags_ptr: *const u8,
pub execution_flags_len: usize,
}Expand description
Configuration options for the benchmark.
Fields
working_dir_ptr: *const u8The working directory where benchmarks should be executed.
working_dir_len: usizestdout_path_ptr: *const u8The file path that should be created and used as stdout.
stdout_path_len: usizestderr_path_ptr: *const u8The file path that should be created and used as stderr.
stderr_path_len: usizestdin_path_ptr: *const u8The (optional) file path that should be opened and used as stdin. If
not provided, then the WASI context will not have a stdin initialized.
stdin_path_len: usizecompilation_timer: *mut u8The functions to start and stop performance timers/counters during Wasm compilation.
compilation_start: extern "C" fn(*mut u8)compilation_end: extern "C" fn(*mut u8)instantiation_timer: *mut u8The functions to start and stop performance timers/counters during Wasm instantiation.
instantiation_start: extern "C" fn(*mut u8)instantiation_end: extern "C" fn(*mut u8)execution_timer: *mut u8The functions to start and stop performance timers/counters during Wasm execution.
execution_start: extern "C" fn(*mut u8)execution_end: extern "C" fn(*mut u8)execution_flags_ptr: *const u8The (optional) flags to use when running Wasmtime. These correspond to the flags used when running Wasmtime from the command line.
execution_flags_len: usizeAuto Trait Implementations
impl !Send for WasmBenchConfig
impl !Sync for WasmBenchConfig
impl Freeze for WasmBenchConfig
impl RefUnwindSafe for WasmBenchConfig
impl Unpin for WasmBenchConfig
impl UnsafeUnpin for WasmBenchConfig
impl UnwindSafe for WasmBenchConfig